@@ -45,6 +45,7 @@ class ServerModel(BaseModel):
     a2s_rules_cache_lifetime: int = 5
     a2s_players_cache_lifetime: int = 1
     src_query_port_lifetime: int = 10
+    no_a2s_rules: bool = False
 
     class Config:
         extra = Extra.forbid
@@ -61,7 +62,7 @@ class EBPFModel(BaseModel):
 
 class Settings(BaseSettings):
     sentry_dsn: typing.Optional[AnyHttpUrl] = None
-    confdir_0: pathlib.Path = '/etc/sqporxy/conf.d/'
+    confdir_0: pathlib.Path = '/etc/sqproxy/conf.d/'
     confdir_1: pathlib.Path = './conf.d/'
     error_log: pathlib.Path = '/var/log/sqproxy/error.log'
     debug_log: pathlib.Path = '/var/log/sqproxy/debug.log'
